@@ -10,7 +10,7 @@ use Data::Object::Library qw(
 
 extends 'API::Client';
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 our $DEFAULT_URL = "https://api.stripe.com";
 
@@ -62,10 +62,17 @@ method PREPARE ($ua, $tx, %args) {
 
     my $headers = $tx->req->headers;
     my $url     = $tx->req->url;
+    my $method  = $tx->req->method;
+    my $content = 'application/json';
+
+    if (grep lc $method eq $_, qw(delete patch post put)) {
+
+        $content = 'application/x-www-form-urlencoded';
+
+    }
 
     # default headers
-    # $headers->header('Content-Type' => 'application/json');
-    # $headers->header('Content-Type' => 'application/x-www-form-urlencoded');
+    $headers->header('Content-Type' => $content);
 
     return $self;
 
@@ -110,7 +117,7 @@ API::Stripe - Stripe.com API Client
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
